make_beacon_sel_proxy

Function make_beacon_sel_proxy 

pub const fn make_beacon_sel_proxy(beacon: [u8; 20]) -> [u8; 90]
Create a proxy that calls “implementation(bytes4)” on the beacon address given with the selector in the calldata to this proxy. Use the returned address as the target of a delegatecall.